extern void cdfbet(int*,double*,double*,double*,double*,double*,double*,
	    int*,double*);
extern void cdfbin(int*,double*,double*,double*,double*,double*,double*,
	    int*,double*);
extern void cdfchi(int*,double*,double*,double*,double*,int*,double*);
extern void cdfchn(int*,double*,double*,double*,double*,double*,int*,double*);
extern void cdff(int*,double*,double*,double*,double*,double*,int*,double*);
extern void cdffnc(int*,double*,double*,double*,double*,double*,double*,
	    int*s,double*);
extern void cdfgam(int*,double*,double*,double*,double*,double*,int*,double*);
extern void cdfnbn(int*,double*,double*,double*,double*,double*,double*,
	    int*,double*);
extern void cdfnor(int*,double*,double*,double*,double*,double*,int*,double*);
extern void cdfpoi(int*,double*,double*,double*,double*,int*,double*);
extern void cdft(int*,double*,double*,double*,double*,int*,double*);
extern void cdftnc(int*,double*,double*,double*,double*,double*,int*,double*);
